# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.edit_root_json_schema import EditRootJsonSchema
from .edit_create_async_request_config_advanced_options import EditCreateAsyncRequestConfigAdvancedOptions


class EditCreateAsyncRequestConfig(UncheckedBaseModel):
    """
    Configuration for the edit operation. Field values should be specified using `extend_edit:value` on each field in the schema.
    """

    schema_: typing_extensions.Annotated[typing.Optional[EditRootJsonSchema], FieldMetadata(alias="schema")] = (
        pydantic.Field(alias="schema", default=None)
    )
    instructions: typing.Optional[str] = pydantic.Field(default=None)
    """
    Custom instructions for the edit operation.
    """

    advanced_options: typing_extensions.Annotated[
        typing.Optional[EditCreateAsyncRequestConfigAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    """
    Advanced options for the edit operation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EditCreateAsyncRequestConfig)
