# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ApiVersionEnum,
        ArrayStrategy,
        ArrayStrategyType,
        BadRequestErrorBody,
        BadRequestErrorBodyCode,
        BaseMetrics,
        BatchProcessorRun,
        BatchProcessorRunMetrics,
        BatchProcessorRunOptions,
        BatchProcessorRunSource,
        BatchProcessorRunStatus,
        BatchWorkflowRunFileInput,
        Block,
        BlockBoundingBox,
        BlockDetails,
        BlockMetadata,
        BlockMetadataPage,
        BlockPolygonItem,
        BlockType,
        Chunk,
        ChunkMetadata,
        ChunkMetadataPageRange,
        ChunkType,
        Citation,
        Classification,
        ClassificationAdvancedOptions,
        ClassificationAdvancedOptionsContext,
        ClassificationConfig,
        ClassificationConfigBaseProcessor,
        ClassificationFieldMetrics,
        ClassifierOutput,
        ClassifyMetrics,
        ClassifyOptimizerOptions,
        DocumentProcessorRunCredits,
        EditBoundingBox,
        EditError,
        EditErrorCode,
        EditJsonSchema,
        EditJsonSchemaExtendEditFieldType,
        EditObjectJsonSchema,
        EditRootJsonSchema,
        EditRun,
        EditRunConfig,
        EditRunConfigAdvancedOptions,
        EditRunEditedFile,
        EditRunMetrics,
        EditRunStatus,
        EditRunStatusStatus,
        EditRunUsage,
        EditTextOptions,
        EmptyBlockDetails,
        Enum,
        EnumOption,
        Error,
        EvaluationSet,
        EvaluationSetItem,
        ExcelSheetRange,
        ExtendError,
        ExtractChunkingOptions,
        ExtractChunkingOptionsChunkSelectionStrategy,
        ExtractChunkingOptionsChunkingStrategy,
        ExtractMetrics,
        ExtractMetricsFieldMetrics,
        ExtractOptimizerOptions,
        ExtractionAdvancedOptions,
        ExtractionAdvancedOptionsArrayCitationStrategy,
        ExtractionAdvancedOptionsExcelSheetSelectionStrategy,
        ExtractionAdvancedOptionsReviewAgent,
        ExtractionConfig,
        ExtractionConfigBaseProcessor,
        ExtractionField,
        ExtractionFieldMetrics,
        ExtractionFieldResult,
        ExtractionFieldResultReference,
        ExtractionFieldResultReferenceBoundingBoxesItem,
        ExtractionFieldResultType,
        ExtractionFieldType,
        ExtractionOutput,
        ExtractionOutputEdits,
        FieldsArrayOutput,
        FigureDetails,
        FigureDetailsFigureType,
        File,
        FileContents,
        FileContentsPagesItem,
        FileContentsSheetsItem,
        FileCredits,
        FileMetadata,
        FileMetadataParentSplit,
        FileType,
        Insight,
        InsightType,
        JsonObject,
        JsonOutput,
        JsonOutputMetadataValue,
        JsonOutputMetadataValueCitationsItem,
        JsonOutputMetadataValueCitationsItemPolygonItem,
        ListProcessorsProcessor,
        ListProcessorsProcessorVersion,
        ListProcessorsResponse,
        MaxPageSize,
        NextPageToken,
        OptimizerBatchProcessorRunResult,
        OptimizerBatchProcessorRunResultProcessorConfig,
        OptimizerBatchProcessorRunResultProcessorConfig_Classify,
        OptimizerBatchProcessorRunResultProcessorConfig_Extract,
        OptimizerRun,
        OptimizerRunAgentType,
        OptimizerRunMetrics,
        OptimizerRunMetricsFieldsItem,
        OptimizerRunStatus,
        OutputMetadata,
        OutputMetadataValue,
        PageRanges,
        PageRangesItem,
        ParseAsyncRequestFile,
        ParseConfig,
        ParseConfigAdvancedOptions,
        ParseConfigBlockOptions,
        ParseConfigBlockOptionsFigures,
        ParseConfigBlockOptionsTables,
        ParseConfigBlockOptionsTablesTargetFormat,
        ParseConfigBlockOptionsText,
        ParseConfigChunkingStrategy,
        ParseConfigChunkingStrategyOptions,
        ParseConfigChunkingStrategyType,
        ParseConfigTarget,
        ParseError,
        ParseErrorCode,
        ParseRequestFile,
        ParseRequestResponseType,
        ParserRun,
        ParserRunCredits,
        ParserRunMetrics,
        ParserRunStatus,
        ParserRunStatusEnum,
        ParserRunStatusStatus,
        Polygon,
        Processor,
        ProcessorId,
        ProcessorOutput,
        ProcessorRun,
        ProcessorRunConfig,
        ProcessorRunConfig_Classify,
        ProcessorRunConfig_Extract,
        ProcessorRunConfig_Splitter,
        ProcessorRunFileInput,
        ProcessorRunMergedProcessorsItem,
        ProcessorRunSummary,
        ProcessorRunSummaryType,
        ProcessorRunType,
        ProcessorStatus,
        ProcessorType,
        ProcessorVersion,
        ProcessorVersionConfig,
        ProcessorVersionConfig_Classify,
        ProcessorVersionConfig_Extract,
        ProcessorVersionConfig_Splitter,
        ProvidedClassifierOutput,
        ProvidedExtractionFieldResult,
        ProvidedExtractionFieldResultType,
        ProvidedExtractionOutput,
        ProvidedFieldsArrayOutput,
        ProvidedJsonOutput,
        ProvidedProcessorOutput,
        ProvidedSplitterOutput,
        ProvidedSplitterOutputSplitsItem,
        SortByEnum,
        SortDirEnum,
        SplitterAdvancedOptions,
        SplitterAdvancedOptionsSplitMethod,
        SplitterConfig,
        SplitterConfigBaseProcessor,
        SplitterMetrics,
        SplitterOutput,
        SplitterOutputSplitsItem,
        StepRun,
        StepRunOutput,
        StepRunOutputRulesItem,
        StepRunOutputRulesItemFailureReason,
        StepRunStatus,
        StepRunStep,
        StepRunStepType,
        TableCellDetails,
        TableDetails,
        TooManyRequestsErrorBody,
        WebhookEvent,
        WebhookEventEventType,
        WebhookEventPayload,
        WebhookEventProcessor,
        WebhookEventProcessorEventType,
        WebhookEventProcessorRun,
        WebhookEventProcessorRunEventType,
        WebhookEventProcessorVersion,
        WebhookEventWorkflow,
        WebhookEventWorkflowEventType,
        WebhookEventWorkflowRun,
        WebhookEventWorkflowRunEventType,
        Workflow,
        WorkflowRun,
        WorkflowRunCredits,
        WorkflowRunFileInput,
        WorkflowRunFileInputOutputsItem,
        WorkflowRunSummary,
        WorkflowStatus,
    )
    from .errors import (
        BadRequestError,
        InternalServerError,
        NotFoundError,
        PaymentRequiredError,
        TooManyRequestsError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        batch_processor_run,
        batch_workflow_run,
        edit,
        evaluation_set,
        evaluation_set_item,
        file,
        parser_run,
        processor,
        processor_run,
        processor_version,
        workflow,
        workflow_run,
        workflow_run_output,
    )
    from .batch_processor_run import BatchProcessorRunGetResponse
    from .batch_workflow_run import BatchWorkflowRunCreateRequestInputsItem, BatchWorkflowRunCreateResponse
    from .client import AsyncExtend, Extend
    from .edit import (
        EditCreateAsyncRequestConfig,
        EditCreateAsyncRequestConfigAdvancedOptions,
        EditCreateAsyncRequestFile,
        EditCreateRequestConfig,
        EditCreateRequestConfigAdvancedOptions,
        EditCreateRequestFile,
        EditDeleteResponse,
        EditGetResponse,
        EditGetResponseEditRun,
        EditGetResponseEditRun_EditRun,
        EditGetResponseEditRun_EditRunStatus,
    )
    from .environment import ExtendEnvironment
    from .evaluation_set import EvaluationSetCreateResponse, EvaluationSetGetResponse, EvaluationSetListResponse
    from .evaluation_set_item import (
        EvaluationSetItemCreateBatchRequestItemsItem,
        EvaluationSetItemCreateBatchResponse,
        EvaluationSetItemCreateResponse,
        EvaluationSetItemDeleteResponse,
        EvaluationSetItemListResponse,
        EvaluationSetItemUpdateResponse,
    )
    from .file import FileDeleteResponse, FileGetResponse, FileListResponse, FileUploadResponse
    from .parser_run import (
        ParserRunDeleteResponse,
        ParserRunGetRequestResponseType,
        ParserRunGetResponse,
        ParserRunGetResponseParserRun,
        ParserRunGetResponseParserRun_ParserRun,
        ParserRunGetResponseParserRun_ParserRunStatus,
    )
    from .processor import (
        ProcessorCreateRequestConfig,
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_Splitter,
        ProcessorCreateResponse,
        ProcessorListRequestSortBy,
        ProcessorListRequestSortDir,
        ProcessorUpdateRequestConfig,
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_Splitter,
        ProcessorUpdateResponse,
    )
    from .processor_run import (
        ProcessorRunCancelResponse,
        ProcessorRunCreateRequestConfig,
        ProcessorRunCreateRequestConfig_Classify,
        ProcessorRunCreateRequestConfig_Extract,
        ProcessorRunCreateRequestConfig_Splitter,
        ProcessorRunCreateResponse,
        ProcessorRunDeleteResponse,
        ProcessorRunGetResponse,
        ProcessorRunListRequestSource,
        ProcessorRunListResponse,
    )
    from .processor_version import (
        ProcessorVersionCreateRequestConfig,
        ProcessorVersionCreateRequestConfig_Classify,
        ProcessorVersionCreateRequestConfig_Extract,
        ProcessorVersionCreateRequestConfig_Splitter,
        ProcessorVersionCreateRequestReleaseType,
        ProcessorVersionCreateResponse,
        ProcessorVersionGetResponse,
        ProcessorVersionListResponse,
    )
    from .version import __version__
    from .workflow import WorkflowCreateResponse
    from .workflow_run import (
        WorkflowRunCancelResponse,
        WorkflowRunCancelResponseWorkflowRun,
        WorkflowRunCreateResponse,
        WorkflowRunDeleteResponse,
        WorkflowRunGetResponse,
        WorkflowRunListResponse,
        WorkflowRunUpdateResponse,
    )
    from .workflow_run_output import WorkflowRunOutputUpdateResponse
_dynamic_imports: typing.Dict[str, str] = {
    "ApiVersionEnum": ".types",
    "ArrayStrategy": ".types",
    "ArrayStrategyType": ".types",
    "AsyncExtend": ".client",
    "BadRequestError": ".errors",
    "BadRequestErrorBody": ".types",
    "BadRequestErrorBodyCode": ".types",
    "BaseMetrics": ".types",
    "BatchProcessorRun": ".types",
    "BatchProcessorRunGetResponse": ".batch_processor_run",
    "BatchProcessorRunMetrics": ".types",
    "BatchProcessorRunOptions": ".types",
    "BatchProcessorRunSource": ".types",
    "BatchProcessorRunStatus": ".types",
    "BatchWorkflowRunCreateRequestInputsItem": ".batch_workflow_run",
    "BatchWorkflowRunCreateResponse": ".batch_workflow_run",
    "BatchWorkflowRunFileInput": ".types",
    "Block": ".types",
    "BlockBoundingBox": ".types",
    "BlockDetails": ".types",
    "BlockMetadata": ".types",
    "BlockMetadataPage": ".types",
    "BlockPolygonItem": ".types",
    "BlockType": ".types",
    "Chunk": ".types",
    "ChunkMetadata": ".types",
    "ChunkMetadataPageRange": ".types",
    "ChunkType": ".types",
    "Citation": ".types",
    "Classification": ".types",
    "ClassificationAdvancedOptions": ".types",
    "ClassificationAdvancedOptionsContext": ".types",
    "ClassificationConfig": ".types",
    "ClassificationConfigBaseProcessor": ".types",
    "ClassificationFieldMetrics": ".types",
    "ClassifierOutput": ".types",
    "ClassifyMetrics": ".types",
    "ClassifyOptimizerOptions": ".types",
    "DocumentProcessorRunCredits": ".types",
    "EditBoundingBox": ".types",
    "EditCreateAsyncRequestConfig": ".edit",
    "EditCreateAsyncRequestConfigAdvancedOptions": ".edit",
    "EditCreateAsyncRequestFile": ".edit",
    "EditCreateRequestConfig": ".edit",
    "EditCreateRequestConfigAdvancedOptions": ".edit",
    "EditCreateRequestFile": ".edit",
    "EditDeleteResponse": ".edit",
    "EditError": ".types",
    "EditErrorCode": ".types",
    "EditGetResponse": ".edit",
    "EditGetResponseEditRun": ".edit",
    "EditGetResponseEditRun_EditRun": ".edit",
    "EditGetResponseEditRun_EditRunStatus": ".edit",
    "EditJsonSchema": ".types",
    "EditJsonSchemaExtendEditFieldType": ".types",
    "EditObjectJsonSchema": ".types",
    "EditRootJsonSchema": ".types",
    "EditRun": ".types",
    "EditRunConfig": ".types",
    "EditRunConfigAdvancedOptions": ".types",
    "EditRunEditedFile": ".types",
    "EditRunMetrics": ".types",
    "EditRunStatus": ".types",
    "EditRunStatusStatus": ".types",
    "EditRunUsage": ".types",
    "EditTextOptions": ".types",
    "EmptyBlockDetails": ".types",
    "Enum": ".types",
    "EnumOption": ".types",
    "Error": ".types",
    "EvaluationSet": ".types",
    "EvaluationSetCreateResponse": ".evaluation_set",
    "EvaluationSetGetResponse": ".evaluation_set",
    "EvaluationSetItem": ".types",
    "EvaluationSetItemCreateBatchRequestItemsItem": ".evaluation_set_item",
    "EvaluationSetItemCreateBatchResponse": ".evaluation_set_item",
    "EvaluationSetItemCreateResponse": ".evaluation_set_item",
    "EvaluationSetItemDeleteResponse": ".evaluation_set_item",
    "EvaluationSetItemListResponse": ".evaluation_set_item",
    "EvaluationSetItemUpdateResponse": ".evaluation_set_item",
    "EvaluationSetListResponse": ".evaluation_set",
    "ExcelSheetRange": ".types",
    "Extend": ".client",
    "ExtendEnvironment": ".environment",
    "ExtendError": ".types",
    "ExtractChunkingOptions": ".types",
    "ExtractChunkingOptionsChunkSelectionStrategy": ".types",
    "ExtractChunkingOptionsChunkingStrategy": ".types",
    "ExtractMetrics": ".types",
    "ExtractMetricsFieldMetrics": ".types",
    "ExtractOptimizerOptions": ".types",
    "ExtractionAdvancedOptions": ".types",
    "ExtractionAdvancedOptionsArrayCitationStrategy": ".types",
    "ExtractionAdvancedOptionsExcelSheetSelectionStrategy": ".types",
    "ExtractionAdvancedOptionsReviewAgent": ".types",
    "ExtractionConfig": ".types",
    "ExtractionConfigBaseProcessor": ".types",
    "ExtractionField": ".types",
    "ExtractionFieldMetrics": ".types",
    "ExtractionFieldResult": ".types",
    "ExtractionFieldResultReference": ".types",
    "ExtractionFieldResultReferenceBoundingBoxesItem": ".types",
    "ExtractionFieldResultType": ".types",
    "ExtractionFieldType": ".types",
    "ExtractionOutput": ".types",
    "ExtractionOutputEdits": ".types",
    "FieldsArrayOutput": ".types",
    "FigureDetails": ".types",
    "FigureDetailsFigureType": ".types",
    "File": ".types",
    "FileContents": ".types",
    "FileContentsPagesItem": ".types",
    "FileContentsSheetsItem": ".types",
    "FileCredits": ".types",
    "FileDeleteResponse": ".file",
    "FileGetResponse": ".file",
    "FileListResponse": ".file",
    "FileMetadata": ".types",
    "FileMetadataParentSplit": ".types",
    "FileType": ".types",
    "FileUploadResponse": ".file",
    "Insight": ".types",
    "InsightType": ".types",
    "InternalServerError": ".errors",
    "JsonObject": ".types",
    "JsonOutput": ".types",
    "JsonOutputMetadataValue": ".types",
    "JsonOutputMetadataValueCitationsItem": ".types",
    "JsonOutputMetadataValueCitationsItemPolygonItem": ".types",
    "ListProcessorsProcessor": ".types",
    "ListProcessorsProcessorVersion": ".types",
    "ListProcessorsResponse": ".types",
    "MaxPageSize": ".types",
    "NextPageToken": ".types",
    "NotFoundError": ".errors",
    "OptimizerBatchProcessorRunResult": ".types",
    "OptimizerBatchProcessorRunResultProcessorConfig": ".types",
    "OptimizerBatchProcessorRunResultProcessorConfig_Classify": ".types",
    "OptimizerBatchProcessorRunResultProcessorConfig_Extract": ".types",
    "OptimizerRun": ".types",
    "OptimizerRunAgentType": ".types",
    "OptimizerRunMetrics": ".types",
    "OptimizerRunMetricsFieldsItem": ".types",
    "OptimizerRunStatus": ".types",
    "OutputMetadata": ".types",
    "OutputMetadataValue": ".types",
    "PageRanges": ".types",
    "PageRangesItem": ".types",
    "ParseAsyncRequestFile": ".types",
    "ParseConfig": ".types",
    "ParseConfigAdvancedOptions": ".types",
    "ParseConfigBlockOptions": ".types",
    "ParseConfigBlockOptionsFigures": ".types",
    "ParseConfigBlockOptionsTables": ".types",
    "ParseConfigBlockOptionsTablesTargetFormat": ".types",
    "ParseConfigBlockOptionsText": ".types",
    "ParseConfigChunkingStrategy": ".types",
    "ParseConfigChunkingStrategyOptions": ".types",
    "ParseConfigChunkingStrategyType": ".types",
    "ParseConfigTarget": ".types",
    "ParseError": ".types",
    "ParseErrorCode": ".types",
    "ParseRequestFile": ".types",
    "ParseRequestResponseType": ".types",
    "ParserRun": ".types",
    "ParserRunCredits": ".types",
    "ParserRunDeleteResponse": ".parser_run",
    "ParserRunGetRequestResponseType": ".parser_run",
    "ParserRunGetResponse": ".parser_run",
    "ParserRunGetResponseParserRun": ".parser_run",
    "ParserRunGetResponseParserRun_ParserRun": ".parser_run",
    "ParserRunGetResponseParserRun_ParserRunStatus": ".parser_run",
    "ParserRunMetrics": ".types",
    "ParserRunStatus": ".types",
    "ParserRunStatusEnum": ".types",
    "ParserRunStatusStatus": ".types",
    "PaymentRequiredError": ".errors",
    "Polygon": ".types",
    "Processor": ".types",
    "ProcessorCreateRequestConfig": ".processor",
    "ProcessorCreateRequestConfig_Classify": ".processor",
    "ProcessorCreateRequestConfig_Extract": ".processor",
    "ProcessorCreateRequestConfig_Splitter": ".processor",
    "ProcessorCreateResponse": ".processor",
    "ProcessorId": ".types",
    "ProcessorListRequestSortBy": ".processor",
    "ProcessorListRequestSortDir": ".processor",
    "ProcessorOutput": ".types",
    "ProcessorRun": ".types",
    "ProcessorRunCancelResponse": ".processor_run",
    "ProcessorRunConfig": ".types",
    "ProcessorRunConfig_Classify": ".types",
    "ProcessorRunConfig_Extract": ".types",
    "ProcessorRunConfig_Splitter": ".types",
    "ProcessorRunCreateRequestConfig": ".processor_run",
    "ProcessorRunCreateRequestConfig_Classify": ".processor_run",
    "ProcessorRunCreateRequestConfig_Extract": ".processor_run",
    "ProcessorRunCreateRequestConfig_Splitter": ".processor_run",
    "ProcessorRunCreateResponse": ".processor_run",
    "ProcessorRunDeleteResponse": ".processor_run",
    "ProcessorRunFileInput": ".types",
    "ProcessorRunGetResponse": ".processor_run",
    "ProcessorRunListRequestSource": ".processor_run",
    "ProcessorRunListResponse": ".processor_run",
    "ProcessorRunMergedProcessorsItem": ".types",
    "ProcessorRunSummary": ".types",
    "ProcessorRunSummaryType": ".types",
    "ProcessorRunType": ".types",
    "ProcessorStatus": ".types",
    "ProcessorType": ".types",
    "ProcessorUpdateRequestConfig": ".processor",
    "ProcessorUpdateRequestConfig_Classify": ".processor",
    "ProcessorUpdateRequestConfig_Extract": ".processor",
    "ProcessorUpdateRequestConfig_Splitter": ".processor",
    "ProcessorUpdateResponse": ".processor",
    "ProcessorVersion": ".types",
    "ProcessorVersionConfig": ".types",
    "ProcessorVersionConfig_Classify": ".types",
    "ProcessorVersionConfig_Extract": ".types",
    "ProcessorVersionConfig_Splitter": ".types",
    "ProcessorVersionCreateRequestConfig": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Classify": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Extract": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Splitter": ".processor_version",
    "ProcessorVersionCreateRequestReleaseType": ".processor_version",
    "ProcessorVersionCreateResponse": ".processor_version",
    "ProcessorVersionGetResponse": ".processor_version",
    "ProcessorVersionListResponse": ".processor_version",
    "ProvidedClassifierOutput": ".types",
    "ProvidedExtractionFieldResult": ".types",
    "ProvidedExtractionFieldResultType": ".types",
    "ProvidedExtractionOutput": ".types",
    "ProvidedFieldsArrayOutput": ".types",
    "ProvidedJsonOutput": ".types",
    "ProvidedProcessorOutput": ".types",
    "ProvidedSplitterOutput": ".types",
    "ProvidedSplitterOutputSplitsItem": ".types",
    "SortByEnum": ".types",
    "SortDirEnum": ".types",
    "SplitterAdvancedOptions": ".types",
    "SplitterAdvancedOptionsSplitMethod": ".types",
    "SplitterConfig": ".types",
    "SplitterConfigBaseProcessor": ".types",
    "SplitterMetrics": ".types",
    "SplitterOutput": ".types",
    "SplitterOutputSplitsItem": ".types",
    "StepRun": ".types",
    "StepRunOutput": ".types",
    "StepRunOutputRulesItem": ".types",
    "StepRunOutputRulesItemFailureReason": ".types",
    "StepRunStatus": ".types",
    "StepRunStep": ".types",
    "StepRunStepType": ".types",
    "TableCellDetails": ".types",
    "TableDetails": ".types",
    "TooManyRequestsError": ".errors",
    "TooManyRequestsErrorBody": ".types",
    "UnauthorizedError": ".errors",
    "UnprocessableEntityError": ".errors",
    "WebhookEvent": ".types",
    "WebhookEventEventType": ".types",
    "WebhookEventPayload": ".types",
    "WebhookEventProcessor": ".types",
    "WebhookEventProcessorEventType": ".types",
    "WebhookEventProcessorRun": ".types",
    "WebhookEventProcessorRunEventType": ".types",
    "WebhookEventProcessorVersion": ".types",
    "WebhookEventWorkflow": ".types",
    "WebhookEventWorkflowEventType": ".types",
    "WebhookEventWorkflowRun": ".types",
    "WebhookEventWorkflowRunEventType": ".types",
    "Workflow": ".types",
    "WorkflowCreateResponse": ".workflow",
    "WorkflowRun": ".types",
    "WorkflowRunCancelResponse": ".workflow_run",
    "WorkflowRunCancelResponseWorkflowRun": ".workflow_run",
    "WorkflowRunCreateResponse": ".workflow_run",
    "WorkflowRunCredits": ".types",
    "WorkflowRunDeleteResponse": ".workflow_run",
    "WorkflowRunFileInput": ".types",
    "WorkflowRunFileInputOutputsItem": ".types",
    "WorkflowRunGetResponse": ".workflow_run",
    "WorkflowRunListResponse": ".workflow_run",
    "WorkflowRunOutputUpdateResponse": ".workflow_run_output",
    "WorkflowRunSummary": ".types",
    "WorkflowRunUpdateResponse": ".workflow_run",
    "WorkflowStatus": ".types",
    "__version__": ".version",
    "batch_processor_run": ".batch_processor_run",
    "batch_workflow_run": ".batch_workflow_run",
    "edit": ".edit",
    "evaluation_set": ".evaluation_set",
    "evaluation_set_item": ".evaluation_set_item",
    "file": ".file",
    "parser_run": ".parser_run",
    "processor": ".processor",
    "processor_run": ".processor_run",
    "processor_version": ".processor_version",
    "workflow": ".workflow",
    "workflow_run": ".workflow_run",
    "workflow_run_output": ".workflow_run_output",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiVersionEnum",
    "ArrayStrategy",
    "ArrayStrategyType",
    "AsyncExtend",
    "BadRequestError",
    "BadRequestErrorBody",
    "BadRequestErrorBodyCode",
    "BaseMetrics",
    "BatchProcessorRun",
    "BatchProcessorRunGetResponse",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunOptions",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchWorkflowRunCreateRequestInputsItem",
    "BatchWorkflowRunCreateResponse",
    "BatchWorkflowRunFileInput",
    "Block",
    "BlockBoundingBox",
    "BlockDetails",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockPolygonItem",
    "BlockType",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkType",
    "Citation",
    "Classification",
    "ClassificationAdvancedOptions",
    "ClassificationAdvancedOptionsContext",
    "ClassificationConfig",
    "ClassificationConfigBaseProcessor",
    "ClassificationFieldMetrics",
    "ClassifierOutput",
    "ClassifyMetrics",
    "ClassifyOptimizerOptions",
    "DocumentProcessorRunCredits",
    "EditBoundingBox",
    "EditCreateAsyncRequestConfig",
    "EditCreateAsyncRequestConfigAdvancedOptions",
    "EditCreateAsyncRequestFile",
    "EditCreateRequestConfig",
    "EditCreateRequestConfigAdvancedOptions",
    "EditCreateRequestFile",
    "EditDeleteResponse",
    "EditError",
    "EditErrorCode",
    "EditGetResponse",
    "EditGetResponseEditRun",
    "EditGetResponseEditRun_EditRun",
    "EditGetResponseEditRun_EditRunStatus",
    "EditJsonSchema",
    "EditJsonSchemaExtendEditFieldType",
    "EditObjectJsonSchema",
    "EditRootJsonSchema",
    "EditRun",
    "EditRunConfig",
    "EditRunConfigAdvancedOptions",
    "EditRunEditedFile",
    "EditRunMetrics",
    "EditRunStatus",
    "EditRunStatusStatus",
    "EditRunUsage",
    "EditTextOptions",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "Error",
    "EvaluationSet",
    "EvaluationSetCreateResponse",
    "EvaluationSetGetResponse",
    "EvaluationSetItem",
    "EvaluationSetItemCreateBatchRequestItemsItem",
    "EvaluationSetItemCreateBatchResponse",
    "EvaluationSetItemCreateResponse",
    "EvaluationSetItemDeleteResponse",
    "EvaluationSetItemListResponse",
    "EvaluationSetItemUpdateResponse",
    "EvaluationSetListResponse",
    "ExcelSheetRange",
    "Extend",
    "ExtendEnvironment",
    "ExtendError",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractMetrics",
    "ExtractMetricsFieldMetrics",
    "ExtractOptimizerOptions",
    "ExtractionAdvancedOptions",
    "ExtractionAdvancedOptionsArrayCitationStrategy",
    "ExtractionAdvancedOptionsExcelSheetSelectionStrategy",
    "ExtractionAdvancedOptionsReviewAgent",
    "ExtractionConfig",
    "ExtractionConfigBaseProcessor",
    "ExtractionField",
    "ExtractionFieldMetrics",
    "ExtractionFieldResult",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "ExtractionOutput",
    "ExtractionOutputEdits",
    "FieldsArrayOutput",
    "FigureDetails",
    "FigureDetailsFigureType",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsSheetsItem",
    "FileCredits",
    "FileDeleteResponse",
    "FileGetResponse",
    "FileListResponse",
    "FileMetadata",
    "FileMetadataParentSplit",
    "FileType",
    "FileUploadResponse",
    "Insight",
    "InsightType",
    "InternalServerError",
    "JsonObject",
    "JsonOutput",
    "JsonOutputMetadataValue",
    "JsonOutputMetadataValueCitationsItem",
    "JsonOutputMetadataValueCitationsItemPolygonItem",
    "ListProcessorsProcessor",
    "ListProcessorsProcessorVersion",
    "ListProcessorsResponse",
    "MaxPageSize",
    "NextPageToken",
    "NotFoundError",
    "OptimizerBatchProcessorRunResult",
    "OptimizerBatchProcessorRunResultProcessorConfig",
    "OptimizerBatchProcessorRunResultProcessorConfig_Classify",
    "OptimizerBatchProcessorRunResultProcessorConfig_Extract",
    "OptimizerRun",
    "OptimizerRunAgentType",
    "OptimizerRunMetrics",
    "OptimizerRunMetricsFieldsItem",
    "OptimizerRunStatus",
    "OutputMetadata",
    "OutputMetadataValue",
    "PageRanges",
    "PageRangesItem",
    "ParseAsyncRequestFile",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyType",
    "ParseConfigTarget",
    "ParseError",
    "ParseErrorCode",
    "ParseRequestFile",
    "ParseRequestResponseType",
    "ParserRun",
    "ParserRunCredits",
    "ParserRunDeleteResponse",
    "ParserRunGetRequestResponseType",
    "ParserRunGetResponse",
    "ParserRunGetResponseParserRun",
    "ParserRunGetResponseParserRun_ParserRun",
    "ParserRunGetResponseParserRun_ParserRunStatus",
    "ParserRunMetrics",
    "ParserRunStatus",
    "ParserRunStatusEnum",
    "ParserRunStatusStatus",
    "PaymentRequiredError",
    "Polygon",
    "Processor",
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateResponse",
    "ProcessorId",
    "ProcessorListRequestSortBy",
    "ProcessorListRequestSortDir",
    "ProcessorOutput",
    "ProcessorRun",
    "ProcessorRunCancelResponse",
    "ProcessorRunConfig",
    "ProcessorRunConfig_Classify",
    "ProcessorRunConfig_Extract",
    "ProcessorRunConfig_Splitter",
    "ProcessorRunCreateRequestConfig",
    "ProcessorRunCreateRequestConfig_Classify",
    "ProcessorRunCreateRequestConfig_Extract",
    "ProcessorRunCreateRequestConfig_Splitter",
    "ProcessorRunCreateResponse",
    "ProcessorRunDeleteResponse",
    "ProcessorRunFileInput",
    "ProcessorRunGetResponse",
    "ProcessorRunListRequestSource",
    "ProcessorRunListResponse",
    "ProcessorRunMergedProcessorsItem",
    "ProcessorRunSummary",
    "ProcessorRunSummaryType",
    "ProcessorRunType",
    "ProcessorStatus",
    "ProcessorType",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateResponse",
    "ProcessorVersion",
    "ProcessorVersionConfig",
    "ProcessorVersionConfig_Classify",
    "ProcessorVersionConfig_Extract",
    "ProcessorVersionConfig_Splitter",
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionGetResponse",
    "ProcessorVersionListResponse",
    "ProvidedClassifierOutput",
    "ProvidedExtractionFieldResult",
    "ProvidedExtractionFieldResultType",
    "ProvidedExtractionOutput",
    "ProvidedFieldsArrayOutput",
    "ProvidedJsonOutput",
    "ProvidedProcessorOutput",
    "ProvidedSplitterOutput",
    "ProvidedSplitterOutputSplitsItem",
    "SortByEnum",
    "SortDirEnum",
    "SplitterAdvancedOptions",
    "SplitterAdvancedOptionsSplitMethod",
    "SplitterConfig",
    "SplitterConfigBaseProcessor",
    "SplitterMetrics",
    "SplitterOutput",
    "SplitterOutputSplitsItem",
    "StepRun",
    "StepRunOutput",
    "StepRunOutputRulesItem",
    "StepRunOutputRulesItemFailureReason",
    "StepRunStatus",
    "StepRunStep",
    "StepRunStepType",
    "TableCellDetails",
    "TableDetails",
    "TooManyRequestsError",
    "TooManyRequestsErrorBody",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "WebhookEvent",
    "WebhookEventEventType",
    "WebhookEventPayload",
    "WebhookEventProcessor",
    "WebhookEventProcessorEventType",
    "WebhookEventProcessorRun",
    "WebhookEventProcessorRunEventType",
    "WebhookEventProcessorVersion",
    "WebhookEventWorkflow",
    "WebhookEventWorkflowEventType",
    "WebhookEventWorkflowRun",
    "WebhookEventWorkflowRunEventType",
    "Workflow",
    "WorkflowCreateResponse",
    "WorkflowRun",
    "WorkflowRunCancelResponse",
    "WorkflowRunCancelResponseWorkflowRun",
    "WorkflowRunCreateResponse",
    "WorkflowRunCredits",
    "WorkflowRunDeleteResponse",
    "WorkflowRunFileInput",
    "WorkflowRunFileInputOutputsItem",
    "WorkflowRunGetResponse",
    "WorkflowRunListResponse",
    "WorkflowRunOutputUpdateResponse",
    "WorkflowRunSummary",
    "WorkflowRunUpdateResponse",
    "WorkflowStatus",
    "__version__",
    "batch_processor_run",
    "batch_workflow_run",
    "edit",
    "evaluation_set",
    "evaluation_set_item",
    "file",
    "parser_run",
    "processor",
    "processor_run",
    "processor_version",
    "workflow",
    "workflow_run",
    "workflow_run_output",
]
