# This file was auto-generated by Fern from our API Definition.

import typing

ExtractionAdvancedOptionsExcelSheetSelectionStrategy = typing.Union[
    typing.Literal["intelligent", "all", "first", "last"], typing.Any
]
