# This file was auto-generated by Fern from our API Definition.

import typing

EditJsonSchemaExtendEditFieldType = typing.Union[
    typing.Literal["text", "checkbox", "radio", "dropdown", "optionList", "signature", "table", "unknown"], typing.Any
]
