# This file was auto-generated by Fern from our API Definition.

import typing

ProcessorRunListRequestSource = typing.Union[
    typing.Literal[
        "ADMIN", "BATCH_PROCESSOR_RUN", "PLAYGROUND", "WORKFLOW_CONFIGURATION", "WORKFLOW_RUN", "STUDIO", "API"
    ],
    typing.Any,
]
