# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .insight_type import InsightType


class Insight(UncheckedBaseModel):
    type: InsightType = pydantic.Field()
    """
    The type of insight:
    - `reasoning`: Model reasoning about the extraction decision
    - `issue`: A potential problem or concern identified by the agentic confidence system
    - `review_summary`: A summary explanation from the agentic confidence system about why the field may need manual review
    """

    content: str = pydantic.Field()
    """
    The content of the insight.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
