# This file was auto-generated by Fern from our API Definition.

import typing

from .classification_field_metrics import ClassificationFieldMetrics
from .extraction_field_metrics import ExtractionFieldMetrics

OptimizerRunMetricsFieldsItem = typing.Union[ExtractionFieldMetrics, ClassificationFieldMetrics]
