# This file was auto-generated by Fern from our API Definition.

import typing

ArrayStrategyType = typing.Union[
    typing.Literal["large_array_heuristics", "large_array_max_context", "large_array_overlap_context"], typing.Any
]
