# This file was auto-generated by Fern from our API Definition.

import typing

ProcessorStatus = typing.Union[typing.Literal["PENDING", "PROCESSING", "PROCESSED", "FAILED", "CANCELLED"], typing.Any]
