# This file was auto-generated by Fern from our API Definition.

import typing

OptimizerRunStatus = typing.Union[
    typing.Literal["PENDING", "PROCESSING", "PROCESSED", "FAILED", "STOPPING", "STOPPED"], typing.Any
]
