# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowStatus = typing.Union[
    typing.Literal[
        "PENDING", "PROCESSING", "NEEDS_REVIEW", "REJECTED", "PROCESSED", "FAILED", "CANCELLED", "CANCELLING"
    ],
    typing.Any,
]
