# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from .parser_run_get_response_parser_run import ParserRunGetResponseParserRun


class ParserRunGetResponse(UncheckedBaseModel):
    success: bool
    warning: typing.Optional[str] = pydantic.Field(default=None)
    """
    Warning message about missing API version header if applicable
    """

    parser_run: typing_extensions.Annotated[ParserRunGetResponseParserRun, FieldMetadata(alias="parserRun")] = (
        pydantic.Field(alias="parserRun")
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
